package com.zanxiang.game.module.sdk.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.game.module.mybatis.entity.Agent;
import com.zanxiang.game.module.mybatis.entity.User;
import com.zanxiang.game.module.mybatis.mapper.AgentMapper;
import com.zanxiang.game.module.sdk.service.IAgentService;
import com.zanxiang.game.module.sdk.service.IUserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.util.Strings;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.util.function.Tuple2;
import reactor.util.function.Tuples;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * @author bilingfeng
 */
@Slf4j
@Service
public class AgentServiceImpl extends ServiceImpl<AgentMapper, Agent> implements IAgentService {

    @Autowired
    private IUserService userService;

    public void userAgentUpdate(Long userId, String channel) {

    }

    @Override
    public Tuple2<Long, Map<String, String>> getUserAgentId(String channel, Long shareUserId) {
        if (Strings.isBlank(channel) && shareUserId != null) {
            User user = userService.getById(shareUserId);
            return Tuples.of(user.getAgentId(), Collections.emptyMap());
        }
        if (Strings.isBlank(channel)) {
            return Tuples.of(0L, Collections.emptyMap());
        }
        log.error("接收到的渠道参数 channel : {}", channel);
        //数据解析
        Map<String, String> urlParamMap = this.channelTransform(channel);
        //查询渠道
        String state = urlParamMap.get("state");
        Agent agent = super.getOne(new LambdaQueryWrapper<Agent>()
                .eq(Agent::getAgentKey, state));
        if (agent == null) {
            return Tuples.of(0L, Collections.emptyMap());
        }
        return Tuples.of(agent.getId(), urlParamMap);
    }

    private Map<String, String> channelTransform(String channel) {
        Map<String, String> paramMap = new HashMap<>(11);
        String[] params = channel.split("&");
        for (String param : params) {
            String[] keyValue = param.split("=");
            if (keyValue.length > 1) {
                String key = keyValue[0];
                String value = keyValue[1];
                paramMap.put(key, value);
            }
        }
        return paramMap;
    }
}
